@@ -295,7 +295,7 @@ def sph_harm(Ra, Rb, l, m):
         Ra: complex, Cayley-Klein parameter for spherical harmonic
         Rb: complex, Cayley-Klein parameter for spherical harmonic
         l: int, index of spherical harmonic l >= 0
-        m: int, index of spherical harmonic -l <= m <= l
+        layer: int, index of spherical harmonic -l <= layer <= l
 
     The spherical harmonics are a subset of Wigner-D matrices,
     and can be calculated in the same manner
@@ -540,7 +540,7 @@ def compute_carray_wD(x, y, z, ri, alpha, rcut, nmax, lmax, w, clist, dclist):
         ellpl1 = np.sum(np.arange(0, l + 2, 1) * 2)
         ellm1 = np.sum(np.arange(0, l, 1) * 2)
         for m in range(-l, l + 1, 1):
-            # get indices of l+1 and l-1 spherical harmonics for m = 0
+            # get indices of l+1 and l-1 spherical harmonics for layer = 0
 
             # get the gradient of spherical harmonics with respect to
             # covariant spherical coordinates VMK 5.8.3
